@@ -8,6 +8,7 @@ import json
 from mypylib import get_trade_days
 from typing import Union
 from collections import defaultdict
+from mypylib import parse_date_time
 
 
 # {"AskPrice": [46.9, 46.95, 47.0, 47.2, 47.3],
@@ -26,7 +27,8 @@ class Quote(dict):
 
     def ts(self):
         if self.timestamp is None:
-            self.timestamp = datetime.datetime.strptime(f'{self.Date()} {self.Time()}', '%Y/%m/%d %H:%M:%S.%f')
+            # self.timestamp = datetime.datetime.strptime(f'{self.Date()} {self.Time()}', '%Y/%m/%d %H:%M:%S.%f')
+            self.timestamp = parse_date_time(self.Date(), self.Time())
         return self.timestamp
 
     def Simtrade(self):
@@ -88,7 +90,8 @@ class Market(dict):
 
     def ts(self):
         if self.timestamp is None:
-            self.timestamp = datetime.datetime.strptime(f'{self.Date()} {self.Time()}', '%Y/%m/%d %H:%M:%S.%f')
+            # self.timestamp = datetime.datetime.strptime(f'{self.Date()} {self.Time()}', '%Y/%m/%d %H:%M:%S.%f')
+            self.timestamp = parse_date_time(self.Date(), self.Time())
         return self.timestamp
 
     def Simtrade(self):
